@@ -661,13 +661,19 @@ class One(ConversionMixin):
         Examples
         --------
         intervals = one.load_dataset(eid, '_ibl_trials.intervals.npy')
-        intervals = one.load_dataset(eid, '*trials.intervals*')
+        # Load dataset without specifying extension
+        intervals = one.load_dataset(eid, 'trials.intervals')  # wildcard mode only
+        intervals = one.load_dataset(eid, '*trials.intervals*')  # wildcard mode only
         filepath = one.load_dataset(eid '_ibl_trials.intervals.npy', download_only=True)
         spike_times = one.load_dataset(eid 'spikes.times.npy', collection='alf/probe01')
-        old_spikes = one.load_dataset(eid, ''spikes.times.npy',
+        old_spikes = one.load_dataset(eid, 'spikes.times.npy',
                                       collection='alf/probe01', revision='2020-08-31')
         """
         datasets = self.list_datasets(eid, details=True, query_type=query_type or self.mode)
+        # If only two parts and wildcards are on, append ext wildcard
+        if self.wildcards and isinstance(dataset, str) and len(dataset.split('.')) == 2:
+            dataset += '.*'
+            _logger.info('Appending extension wildcard: ' + dataset)
 
         datasets = util.filter_datasets(datasets, dataset, collection, revision,
                                         wildcards=self.wildcards)
@@ -761,6 +767,9 @@ class One(ConversionMixin):
             return None, all_datasets.iloc[0:0]  # Return empty
 
         # Filter and load missing
+        if self.wildcards:  # Append extension wildcard if 'object.attribute' string
+            datasets = [x + ('.*' if isinstance(x, str) and len(x.split('.')) == 2 else '')
+                        for x in datasets]
         slices = [util.filter_datasets(all_datasets, x, y, z, wildcards=self.wildcards)
                   for x, y, z in zip(datasets, collections, revisions)]
         present = [len(x) == 1 for x in slices]
@@ -1448,14 +1457,29 @@ class OneAlyx(One):
             raise ValueError('Unrecognized name or UUID')
         return self.alyx.rest('datasets', 'read', id=dset)['dataset_type']
 
-    def describe_revision(self, revision):
-        raise NotImplementedError('Requires changes to revisions endpoint')
-        rec = self.alyx.rest('revisions', 'list', name=revision)  # py 3.8
-        # if rec := self.alyx.rest('revisions', 'list', name=revision):  # py 3.8
-        if rec:
-            print(rec[0]['description'])
-        else:
-            print(f'Revision "{revision}" not found')
+    def describe_revision(self, revision, full=False):
+        """Print description of a revision
+
+        Parameters
+        ----------
+        revision : str
+            The name of the revision (without '#')
+        full : bool
+            If true, returns the matching record
+
+        Returns
+        -------
+        None if full is false or no record found, otherwise returns record as dict
+        """
+        try:
+            rec = self.alyx.rest('revisions', 'read', id=revision)
+            print(rec['description'])
+            if full:
+                return rec
+        except requests.exceptions.HTTPError as ex:
+            if ex.response.status_code != 404:
+                raise ex
+            print(f'revision "{revision}" not found')
 
     def _dataset_name2id(self, dset_name, eid=None):
         # TODO finish function
